import {OnChanges, Component, Input, SimpleChanges} from '@angular/core';
import {MessageComponent} from "../message/message.component";
import {FormsModule} from "@angular/forms";
import {NgForOf, NgFor} from "@angular/common";
import axios from 'axios';

@Component({
  selector: 'app-messages',
  standalone: true,
  imports: [
    MessageComponent,
    FormsModule,
    NgForOf,
    NgFor
  ],
  templateUrl: './messages.component.html',
  styleUrl: './messages.component.scss'
})
export class MessagesComponent implements OnChanges {


  @Input() clientId = 0;
  @Input() username = "";
  @Input() apiUrl = "";
  enteredMessage = "";

  messages: Array<MessageData> = [];

  ngOnChanges(changes: SimpleChanges): void {
    if ('clientId' in changes && this.clientId !== 0) {
      this.refreshChat();
      this.triggerRoutine();
    }
  }

  sendMessage() {
    let data : MessageData = {
      clientId: this.clientId,
      username: this.username,
      message: this.enteredMessage
    }
    this.messages.push(data);
    console.log(data);
    this.executePostRequest(data);
    this.enteredMessage = "";
  }

  executePostRequest(data: MessageData) {
    axios.post(this.apiUrl + '/sendMessage', data,{
      headers: {
        'Content-Type': 'application/json',
        'Access-Control-Allow-Origin': '*',
      }
    }).then(response => {
      this.refreshChat();
    })
    .catch(error => {
      console.error("WAS DAS FÜR KACKE!");
    });
  }

  refreshChat(url?: string) {
    let baseUrl = "";
    if(url != null) {
      baseUrl = url;
    } else {
      baseUrl = this.apiUrl;
    }
    console.log(baseUrl)
    axios.get(baseUrl + '/getMessages', {
      headers: {
        'Access-Control-Allow-Origin': '*',
      }
    }).then(response => {
      this.messages = response.data;
    }).catch(error => {
        console.error("WAS DAS FÜR KACKE!");
    });
  }

  triggerRoutine() {
    const intervalId = setInterval(() => {
      this.refreshChat(this.apiUrl);
    }, 1000);
  }
}

interface MessageData {
  clientId: number;
  username: string;
  message: string;
}
